# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from onelogin import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from onelogin import schemas  # noqa: F401

from onelogin.model.alt_err import AltErr
from onelogin.model.user import User

from . import path

# Query params
LimitSchema = schemas.Int32Schema
PageSchema = schemas.IntSchema
CursorSchema = schemas.StrSchema
NameSchema = schemas.StrSchema
IncludeUnassignedSchema = schemas.BoolSchema
RequestRequiredQueryParams = typing_extensions.TypedDict(
    'RequestRequiredQueryParams',
    {
    }
)
RequestOptionalQueryParams = typing_extensions.TypedDict(
    'RequestOptionalQueryParams',
    {
        'limit': typing.Union[LimitSchema, decimal.Decimal, int, ],
        'page': typing.Union[PageSchema, decimal.Decimal, int, ],
        'cursor': typing.Union[CursorSchema, str, ],
        'name': typing.Union[NameSchema, str, ],
        'include_unassigned': typing.Union[IncludeUnassignedSchema, bool, ],
    },
    total=False
)


class RequestQueryParams(RequestRequiredQueryParams, RequestOptionalQueryParams):
    pass


request_query_limit = api_client.QueryParameter(
    name="limit",
    style=api_client.ParameterStyle.FORM,
    schema=LimitSchema,
    explode=True,
)
request_query_page = api_client.QueryParameter(
    name="page",
    style=api_client.ParameterStyle.FORM,
    schema=PageSchema,
    explode=True,
)
request_query_cursor = api_client.QueryParameter(
    name="cursor",
    style=api_client.ParameterStyle.FORM,
    schema=CursorSchema,
    explode=True,
)
request_query_name = api_client.QueryParameter(
    name="name",
    style=api_client.ParameterStyle.FORM,
    schema=NameSchema,
    explode=True,
)
request_query_include_unassigned = api_client.QueryParameter(
    name="include_unassigned",
    style=api_client.ParameterStyle.FORM,
    schema=IncludeUnassignedSchema,
    explode=True,
)
# Path params
RoleIdSchema = schemas.StrSchema
RequestRequiredPathParams = typing_extensions.TypedDict(
    'RequestRequiredPathParams',
    {
        'role_id': typing.Union[RoleIdSchema, str, ],
    }
)
RequestOptionalPathParams = typing_extensions.TypedDict(
    'RequestOptionalPathParams',
    {
    },
    total=False
)


class RequestPathParams(RequestRequiredPathParams, RequestOptionalPathParams):
    pass


request_path_role_id = api_client.PathParameter(
    name="role_id",
    style=api_client.ParameterStyle.SIMPLE,
    schema=RoleIdSchema,
    required=True,
)
_auth = [
    'OAuth2',
]
CurrentPageSchema = schemas.IntSchema
current_page_parameter = api_client.HeaderParameter(
    name="Current-Page",
    style=api_client.ParameterStyle.SIMPLE,
    schema=CurrentPageSchema,
)
PageItemsSchema = schemas.IntSchema
page_items_parameter = api_client.HeaderParameter(
    name="Page-Items",
    style=api_client.ParameterStyle.SIMPLE,
    schema=PageItemsSchema,
)
TotalCountSchema = schemas.IntSchema
total_count_parameter = api_client.HeaderParameter(
    name="Total-Count",
    style=api_client.ParameterStyle.SIMPLE,
    schema=TotalCountSchema,
)
TotalPagesSchema = schemas.IntSchema
total_pages_parameter = api_client.HeaderParameter(
    name="Total-Pages",
    style=api_client.ParameterStyle.SIMPLE,
    schema=TotalPagesSchema,
)


class LinkSchema(
    schemas.ListSchema
):


    class MetaOapg:
        items = schemas.StrSchema

    def __new__(
        cls,
        _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'LinkSchema':
        return super().__new__(
            cls,
            _arg,
            _configuration=_configuration,
        )

    def __getitem__(self, i: int) -> MetaOapg.items:
        return super().__getitem__(i)
link_parameter = api_client.HeaderParameter(
    name="Link",
    style=api_client.ParameterStyle.SIMPLE,
    schema=LinkSchema,
)
BeforeCursorSchema = schemas.StrSchema
before_cursor_parameter = api_client.HeaderParameter(
    name="Before-Cursor",
    style=api_client.ParameterStyle.SIMPLE,
    schema=BeforeCursorSchema,
)
AfterCursorSchema = schemas.StrSchema
after_cursor_parameter = api_client.HeaderParameter(
    name="After-Cursor",
    style=api_client.ParameterStyle.SIMPLE,
    schema=AfterCursorSchema,
)


class SchemaFor200ResponseBodyApplcationJson(
    schemas.ListSchema
):


    class MetaOapg:
        
        @staticmethod
        def items() -> typing.Type['User']:
            return User

    def __new__(
        cls,
        _arg: typing.Union[typing.Tuple['User'], typing.List['User']],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'SchemaFor200ResponseBodyApplcationJson':
        return super().__new__(
            cls,
            _arg,
            _configuration=_configuration,
        )

    def __getitem__(self, i: int) -> 'User':
        return super().__getitem__(i)
ResponseHeadersFor200 = typing_extensions.TypedDict(
    'ResponseHeadersFor200',
    {
        'Current-Page': CurrentPageSchema,
        'Page-Items': PageItemsSchema,
        'Total-Count': TotalCountSchema,
        'Total-Pages': TotalPagesSchema,
        'Link': LinkSchema,
        'Before-Cursor': BeforeCursorSchema,
        'After-Cursor': AfterCursorSchema,
    }
)


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor200ResponseBodyApplcationJson,
    ]
    headers: ResponseHeadersFor200


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
    content={
        'applcation/json': api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplcationJson),
    },
    headers=[
        current_page_parameter,
        page_items_parameter,
        total_count_parameter,
        total_pages_parameter,
        link_parameter,
        before_cursor_parameter,
        after_cursor_parameter,
    ]
)
SchemaFor401ResponseBodyApplicationJson = AltErr


@dataclass
class ApiResponseFor401(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor401ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_401 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor401,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor401ResponseBodyApplicationJson),
    },
)
SchemaFor404ResponseBodyApplicationJson = AltErr


@dataclass
class ApiResponseFor404(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor404ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_404 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor404,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor404ResponseBodyApplicationJson),
    },
)
_status_code_to_response = {
    '200': _response_for_200,
    '401': _response_for_401,
    '404': _response_for_404,
}
_all_accept_content_types = (
    'applcation/json',
    'application/json',
)


class BaseApi(api_client.Api):
    @typing.overload
    def _get_role_users_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def _get_role_users_oapg(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def _get_role_users_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def _get_role_users_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        """
        Get Role Users
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        self._verify_typed_dict_inputs_oapg(RequestQueryParams, query_params)
        self._verify_typed_dict_inputs_oapg(RequestPathParams, path_params)
        used_path = path.value

        _path_params = {}
        for parameter in (
            request_path_role_id,
        ):
            parameter_data = path_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            serialized_data = parameter.serialize(parameter_data)
            _path_params.update(serialized_data)

        for k, v in _path_params.items():
            used_path = used_path.replace('{%s}' % k, v)

        prefix_separator_iterator = None
        for parameter in (
            request_query_limit,
            request_query_page,
            request_query_cursor,
            request_query_name,
            request_query_include_unassigned,
        ):
            parameter_data = query_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            if prefix_separator_iterator is None:
                prefix_separator_iterator = parameter.get_prefix_separator_iterator()
            serialized_data = parameter.serialize(parameter_data, prefix_separator_iterator)
            for serialized_value in serialized_data.values():
                used_path += serialized_value

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        response = self.api_client.call_api(
            resource_path=used_path,
            method='get'.upper(),
            headers=_headers,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(
                status=response.status,
                reason=response.reason,
                api_response=api_response
            )

        return api_response


class GetRoleUsers(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    @typing.overload
    def get_role_users(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def get_role_users(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def get_role_users(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def get_role_users(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._get_role_users_oapg(
            query_params=query_params,
            path_params=path_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForget(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    @typing.overload
    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def get(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._get_role_users_oapg(
            query_params=query_params,
            path_params=path_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )





# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from onelogin import schemas  # noqa: F401


class EmailConfig(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "address",
            "domain",
            "from",
        }
        
        class properties:
            address = schemas.StrSchema
            _from = schemas.StrSchema
            domain = schemas.StrSchema
            use_tls = schemas.BoolSchema
            user_name = schemas.StrSchema
            password = schemas.StrSchema
            port = schemas.IntSchema
            __annotations__ = {
                "address": address,
                "from": _from,
                "domain": domain,
                "use_tls": use_tls,
                "user_name": user_name,
                "password": password,
                "port": port,
            }
    
    address: MetaOapg.properties.address
    domain: MetaOapg.properties.domain
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["from"]) -> MetaOapg.properties._from: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["domain"]) -> MetaOapg.properties.domain: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["use_tls"]) -> MetaOapg.properties.use_tls: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["user_name"]) -> MetaOapg.properties.user_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["password"]) -> MetaOapg.properties.password: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["port"]) -> MetaOapg.properties.port: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["address", "from", "domain", "use_tls", "user_name", "password", "port", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["from"]) -> MetaOapg.properties._from: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["domain"]) -> MetaOapg.properties.domain: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["use_tls"]) -> typing.Union[MetaOapg.properties.use_tls, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["user_name"]) -> typing.Union[MetaOapg.properties.user_name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["password"]) -> typing.Union[MetaOapg.properties.password, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["port"]) -> typing.Union[MetaOapg.properties.port, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["address", "from", "domain", "use_tls", "user_name", "password", "port", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        address: typing.Union[MetaOapg.properties.address, str, ],
        domain: typing.Union[MetaOapg.properties.domain, str, ],
        use_tls: typing.Union[MetaOapg.properties.use_tls, bool, schemas.Unset] = schemas.unset,
        user_name: typing.Union[MetaOapg.properties.user_name, str, schemas.Unset] = schemas.unset,
        password: typing.Union[MetaOapg.properties.password, str, schemas.Unset] = schemas.unset,
        port: typing.Union[MetaOapg.properties.port, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'EmailConfig':
        return super().__new__(
            cls,
            *_args,
            address=address,
            domain=domain,
            use_tls=use_tls,
            user_name=user_name,
            password=password,
            port=port,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.auth_oauth2_v2_token.post import GenerateToken
from onelogin.paths.auth_rate_limit.get import GetRateLimit
from onelogin.paths.auth_oauth2_revoke.post import RevokeTokens


class OAuth2Api(
    GenerateToken,
    GetRateLimit,
    RevokeTokens,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



import typing_extensions

from onelogin.paths import PathValues
from onelogin.apis.paths.auth_oauth2_v2_token import AuthOauth2V2Token
from onelogin.apis.paths.auth_oauth2_revoke import AuthOauth2Revoke
from onelogin.apis.paths.auth_rate_limit import AuthRateLimit
from onelogin.apis.paths.api_2_api_authorizations import Api2ApiAuthorizations
from onelogin.apis.paths.api_2_api_authorizations_api_auth_id import Api2ApiAuthorizationsApiAuthId
from onelogin.apis.paths.api_2_api_authorizations_api_auth_id_scopes import Api2ApiAuthorizationsApiAuthIdScopes
from onelogin.apis.paths.api_2_api_authorizations_api_auth_id_scopes_scope_id import Api2ApiAuthorizationsApiAuthIdScopesScopeId
from onelogin.apis.paths.api_2_api_authorizations_api_auth_id_claims import Api2ApiAuthorizationsApiAuthIdClaims
from onelogin.apis.paths.api_2_api_authorizations_api_auth_id_claims_claim_id import Api2ApiAuthorizationsApiAuthIdClaimsClaimId
from onelogin.apis.paths.api_2_api_authorizations_api_auth_id_clients import Api2ApiAuthorizationsApiAuthIdClients
from onelogin.apis.paths.api_2_api_authorizations_api_auth_id_clients_client_app_id import Api2ApiAuthorizationsApiAuthIdClientsClientAppId
from onelogin.apis.paths.api_1_events import Api1Events
from onelogin.apis.paths.api_1_events_event_id import Api1EventsEventId
from onelogin.apis.paths.api_1_events_types import Api1EventsTypes
from onelogin.apis.paths.api_1_groups import Api1Groups
from onelogin.apis.paths.api_1_groups_group_id import Api1GroupsGroupId
from onelogin.apis.paths.api_1_invites_get_invite_link import Api1InvitesGetInviteLink
from onelogin.apis.paths.api_1_invites_send_invite_link import Api1InvitesSendInviteLink
from onelogin.apis.paths.api_1_users import Api1Users
from onelogin.apis.paths.api_1_users_user_id import Api1UsersUserId
from onelogin.apis.paths.api_1_users_user_id_apps import Api1UsersUserIdApps
from onelogin.apis.paths.api_1_users_user_id_roles import Api1UsersUserIdRoles
from onelogin.apis.paths.api_1_users_set_password_clear_text_user_id import Api1UsersSetPasswordClearTextUserId
from onelogin.apis.paths.api_1_users_set_password_using_salt_user_id import Api1UsersSetPasswordUsingSaltUserId
from onelogin.apis.paths.api_1_users_custom_attributes import Api1UsersCustomAttributes
from onelogin.apis.paths.api_1_users_user_id_auth_factor import Api1UsersUserIdAuthFactor
from onelogin.apis.paths.api_1_users_user_id_logout import Api1UsersUserIdLogout
from onelogin.apis.paths.api_1_users_user_id_lock_user import Api1UsersUserIdLockUser
from onelogin.apis.paths.api_1_users_user_id_otp_devices import Api1UsersUserIdOtpDevices
from onelogin.apis.paths.api_1_users_user_id_mfa_token import Api1UsersUserIdMfaToken
from onelogin.apis.paths.api_1_users_user_id_add_roles import Api1UsersUserIdAddRoles
from onelogin.apis.paths.api_1_users_user_id_set_state import Api1UsersUserIdSetState
from onelogin.apis.paths.api_1_users_user_id_remove_roles import Api1UsersUserIdRemoveRoles
from onelogin.apis.paths.api_1_users_user_id_otp_devices_device_id import Api1UsersUserIdOtpDevicesDeviceId
from onelogin.apis.paths.api_1_users_user_id_otp_devices_device_id_verify import Api1UsersUserIdOtpDevicesDeviceIdVerify
from onelogin.apis.paths.api_1_users_user_id_otp_devices_device_id_trigger import Api1UsersUserIdOtpDevicesDeviceIdTrigger
from onelogin.apis.paths.api_1_privileges import Api1Privileges
from onelogin.apis.paths.api_1_privileges_privilege_id import Api1PrivilegesPrivilegeId
from onelogin.apis.paths.api_1_privileges_privilege_id_roles import Api1PrivilegesPrivilegeIdRoles
from onelogin.apis.paths.api_1_privileges_privilege_id_roles_role_id import Api1PrivilegesPrivilegeIdRolesRoleId
from onelogin.apis.paths.api_1_privileges_privilege_id_users import Api1PrivilegesPrivilegeIdUsers
from onelogin.apis.paths.api_1_privileges_privilege_id_users_user_id import Api1PrivilegesPrivilegeIdUsersUserId
from onelogin.apis.paths.api_1_roles import Api1Roles
from onelogin.apis.paths.api_1_roles_role_id import Api1RolesRoleId
from onelogin.apis.paths.api_1_saml_assertion import Api1SamlAssertion
from onelogin.apis.paths.api_1_saml_assertion_verify_factor import Api1SamlAssertionVerifyFactor
from onelogin.apis.paths.api_2_saml_assertion import Api2SamlAssertion
from onelogin.apis.paths.api_2_saml_assertion_verify_factor import Api2SamlAssertionVerifyFactor
from onelogin.apis.paths.api_2_mappings import Api2Mappings
from onelogin.apis.paths.api_2_mappings_mapping_id import Api2MappingsMappingId
from onelogin.apis.paths.api_2_mappings_conditions import Api2MappingsConditions
from onelogin.apis.paths.api_2_mappings_conditions_mapping_condition_value_operators import Api2MappingsConditionsMappingConditionValueOperators
from onelogin.apis.paths.api_2_mappings_conditions_mapping_condition_value_values import Api2MappingsConditionsMappingConditionValueValues
from onelogin.apis.paths.api_2_mappings_actions import Api2MappingsActions
from onelogin.apis.paths.api_2_mappings_actions_mapping_action_value_values import Api2MappingsActionsMappingActionValueValues
from onelogin.apis.paths.api_2_mappings_sort import Api2MappingsSort
from onelogin.apis.paths.api_2_apps import Api2Apps
from onelogin.apis.paths.api_2_apps_app_id import Api2AppsAppId
from onelogin.apis.paths.api_2_apps_app_id_parameters_parameter_id import Api2AppsAppIdParametersParameterId
from onelogin.apis.paths.api_2_apps_app_id_users import Api2AppsAppIdUsers
from onelogin.apis.paths.api_2_apps_app_id_rules import Api2AppsAppIdRules
from onelogin.apis.paths.api_2_apps_app_id_rules_rule_id import Api2AppsAppIdRulesRuleId
from onelogin.apis.paths.api_2_apps_app_id_rules_conditions import Api2AppsAppIdRulesConditions
from onelogin.apis.paths.api_2_apps_app_id_rules_conditions_rule_condition_value_operators import Api2AppsAppIdRulesConditionsRuleConditionValueOperators
from onelogin.apis.paths.api_2_apps_app_id_rules_conditions_rule_condition_value_values import Api2AppsAppIdRulesConditionsRuleConditionValueValues
from onelogin.apis.paths.api_2_apps_app_id_rules_actions import Api2AppsAppIdRulesActions
from onelogin.apis.paths.api_2_apps_app_id_rules_actions_rule_action_value_values import Api2AppsAppIdRulesActionsRuleActionValueValues
from onelogin.apis.paths.api_2_apps_app_id_rules_sort import Api2AppsAppIdRulesSort
from onelogin.apis.paths.api_2_connectors import Api2Connectors
from onelogin.apis.paths.api_2_risk_rules import Api2RiskRules
from onelogin.apis.paths.api_2_risk_rules_rule_id import Api2RiskRulesRuleId
from onelogin.apis.paths.api_2_risk_events import Api2RiskEvents
from onelogin.apis.paths.api_2_risk_scores import Api2RiskScores
from onelogin.apis.paths.api_2_risk_verify import Api2RiskVerify
from onelogin.apis.paths.api_2_mfa_users_user_id_registrations_registration_id import Api2MfaUsersUserIdRegistrationsRegistrationId
from onelogin.apis.paths.api_2_mfa_users_user_id_registrations import Api2MfaUsersUserIdRegistrations
from onelogin.apis.paths.api_2_mfa_users_user_id_devices import Api2MfaUsersUserIdDevices
from onelogin.apis.paths.api_2_mfa_users_user_id_devices_device_id import Api2MfaUsersUserIdDevicesDeviceId
from onelogin.apis.paths.api_2_mfa_users_user_id_verifications_verification_id import Api2MfaUsersUserIdVerificationsVerificationId
from onelogin.apis.paths.api_2_mfa_users_user_id_verifications import Api2MfaUsersUserIdVerifications
from onelogin.apis.paths.api_2_mfa_users_user_id_factors import Api2MfaUsersUserIdFactors
from onelogin.apis.paths.api_2_mfa_users_user_id_mfa_token import Api2MfaUsersUserIdMfaToken
from onelogin.apis.paths.api_2_roles import Api2Roles
from onelogin.apis.paths.api_2_roles_role_id import Api2RolesRoleId
from onelogin.apis.paths.api_2_roles_role_id_apps import Api2RolesRoleIdApps
from onelogin.apis.paths.api_2_roles_role_id_users import Api2RolesRoleIdUsers
from onelogin.apis.paths.api_2_roles_role_id_admins import Api2RolesRoleIdAdmins
from onelogin.apis.paths.api_2_hooks import Api2Hooks
from onelogin.apis.paths.api_2_hooks_hook_id import Api2HooksHookId
from onelogin.apis.paths.api_2_hooks_hook_id_logs import Api2HooksHookIdLogs
from onelogin.apis.paths.api_2_hooks_envs import Api2HooksEnvs
from onelogin.apis.paths.api_2_hooks_envs_envvar_id import Api2HooksEnvsEnvvarId
from onelogin.apis.paths.api_2_users import Api2Users
from onelogin.apis.paths.api_2_users_user_id import Api2UsersUserId
from onelogin.apis.paths.api_2_users_user_id_apps import Api2UsersUserIdApps
from onelogin.apis.paths.api_2_branding_brands import Api2BrandingBrands
from onelogin.apis.paths.api_2_branding_brands_brand_id import Api2BrandingBrandsBrandId
from onelogin.apis.paths.api_2_branding_brands_brand_id_templates import Api2BrandingBrandsBrandIdTemplates
from onelogin.apis.paths.api_2_branding_brands_brand_id_templates_template_id import Api2BrandingBrandsBrandIdTemplatesTemplateId
from onelogin.apis.paths.api_2_branding_brands_brand_id_apps import Api2BrandingBrandsBrandIdApps
from onelogin.apis.paths.api_2_branding_email_settings import Api2BrandingEmailSettings
from onelogin.apis.paths.api_2_branding_brands_brand_id_templates_template_type_locale import Api2BrandingBrandsBrandIdTemplatesTemplateTypeLocale
from onelogin.apis.paths.api_2_branding_brands_master_templates_template_type import Api2BrandingBrandsMasterTemplatesTemplateType

PathToApi = typing_extensions.TypedDict(
    'PathToApi',
    {
        PathValues.AUTH_OAUTH2_V2_TOKEN: AuthOauth2V2Token,
        PathValues.AUTH_OAUTH2_REVOKE: AuthOauth2Revoke,
        PathValues.AUTH_RATE_LIMIT: AuthRateLimit,
        PathValues.API_2_API_AUTHORIZATIONS: Api2ApiAuthorizations,
        PathValues.API_2_API_AUTHORIZATIONS_API_AUTH_ID: Api2ApiAuthorizationsApiAuthId,
        PathValues.API_2_API_AUTHORIZATIONS_API_AUTH_ID_SCOPES: Api2ApiAuthorizationsApiAuthIdScopes,
        PathValues.API_2_API_AUTHORIZATIONS_API_AUTH_ID_SCOPES_SCOPE_ID: Api2ApiAuthorizationsApiAuthIdScopesScopeId,
        PathValues.API_2_API_AUTHORIZATIONS_API_AUTH_ID_CLAIMS: Api2ApiAuthorizationsApiAuthIdClaims,
        PathValues.API_2_API_AUTHORIZATIONS_API_AUTH_ID_CLAIMS_CLAIM_ID: Api2ApiAuthorizationsApiAuthIdClaimsClaimId,
        PathValues.API_2_API_AUTHORIZATIONS_API_AUTH_ID_CLIENTS: Api2ApiAuthorizationsApiAuthIdClients,
        PathValues.API_2_API_AUTHORIZATIONS_API_AUTH_ID_CLIENTS_CLIENT_APP_ID: Api2ApiAuthorizationsApiAuthIdClientsClientAppId,
        PathValues.API_1_EVENTS: Api1Events,
        PathValues.API_1_EVENTS_EVENT_ID: Api1EventsEventId,
        PathValues.API_1_EVENTS_TYPES: Api1EventsTypes,
        PathValues.API_1_GROUPS: Api1Groups,
        PathValues.API_1_GROUPS_GROUP_ID: Api1GroupsGroupId,
        PathValues.API_1_INVITES_GET_INVITE_LINK: Api1InvitesGetInviteLink,
        PathValues.API_1_INVITES_SEND_INVITE_LINK: Api1InvitesSendInviteLink,
        PathValues.API_1_USERS: Api1Users,
        PathValues.API_1_USERS_USER_ID: Api1UsersUserId,
        PathValues.API_1_USERS_USER_ID_APPS: Api1UsersUserIdApps,
        PathValues.API_1_USERS_USER_ID_ROLES: Api1UsersUserIdRoles,
        PathValues.API_1_USERS_SET_PASSWORD_CLEAR_TEXT_USER_ID: Api1UsersSetPasswordClearTextUserId,
        PathValues.API_1_USERS_SET_PASSWORD_USING_SALT_USER_ID: Api1UsersSetPasswordUsingSaltUserId,
        PathValues.API_1_USERS_CUSTOM_ATTRIBUTES: Api1UsersCustomAttributes,
        PathValues.API_1_USERS_USER_ID_AUTH_FACTOR: Api1UsersUserIdAuthFactor,
        PathValues.API_1_USERS_USER_ID_LOGOUT: Api1UsersUserIdLogout,
        PathValues.API_1_USERS_USER_ID_LOCK_USER: Api1UsersUserIdLockUser,
        PathValues.API_1_USERS_USER_ID_OTP_DEVICES: Api1UsersUserIdOtpDevices,
        PathValues.API_1_USERS_USER_ID_MFA_TOKEN: Api1UsersUserIdMfaToken,
        PathValues.API_1_USERS_USER_ID_ADD_ROLES: Api1UsersUserIdAddRoles,
        PathValues.API_1_USERS_USER_ID_SET_STATE: Api1UsersUserIdSetState,
        PathValues.API_1_USERS_USER_ID_REMOVE_ROLES: Api1UsersUserIdRemoveRoles,
        PathValues.API_1_USERS_USER_ID_OTP_DEVICES_DEVICE_ID: Api1UsersUserIdOtpDevicesDeviceId,
        PathValues.API_1_USERS_USER_ID_OTP_DEVICES_DEVICE_ID_VERIFY: Api1UsersUserIdOtpDevicesDeviceIdVerify,
        PathValues.API_1_USERS_USER_ID_OTP_DEVICES_DEVICE_ID_TRIGGER: Api1UsersUserIdOtpDevicesDeviceIdTrigger,
        PathValues.API_1_PRIVILEGES: Api1Privileges,
        PathValues.API_1_PRIVILEGES_PRIVILEGE_ID: Api1PrivilegesPrivilegeId,
        PathValues.API_1_PRIVILEGES_PRIVILEGE_ID_ROLES: Api1PrivilegesPrivilegeIdRoles,
        PathValues.API_1_PRIVILEGES_PRIVILEGE_ID_ROLES_ROLE_ID: Api1PrivilegesPrivilegeIdRolesRoleId,
        PathValues.API_1_PRIVILEGES_PRIVILEGE_ID_USERS: Api1PrivilegesPrivilegeIdUsers,
        PathValues.API_1_PRIVILEGES_PRIVILEGE_ID_USERS_USER_ID: Api1PrivilegesPrivilegeIdUsersUserId,
        PathValues.API_1_ROLES: Api1Roles,
        PathValues.API_1_ROLES_ROLE_ID: Api1RolesRoleId,
        PathValues.API_1_SAML_ASSERTION: Api1SamlAssertion,
        PathValues.API_1_SAML_ASSERTION_VERIFY_FACTOR: Api1SamlAssertionVerifyFactor,
        PathValues.API_2_SAML_ASSERTION: Api2SamlAssertion,
        PathValues.API_2_SAML_ASSERTION_VERIFY_FACTOR: Api2SamlAssertionVerifyFactor,
        PathValues.API_2_MAPPINGS: Api2Mappings,
        PathValues.API_2_MAPPINGS_MAPPING_ID: Api2MappingsMappingId,
        PathValues.API_2_MAPPINGS_CONDITIONS: Api2MappingsConditions,
        PathValues.API_2_MAPPINGS_CONDITIONS_MAPPING_CONDITION_VALUE_OPERATORS: Api2MappingsConditionsMappingConditionValueOperators,
        PathValues.API_2_MAPPINGS_CONDITIONS_MAPPING_CONDITION_VALUE_VALUES: Api2MappingsConditionsMappingConditionValueValues,
        PathValues.API_2_MAPPINGS_ACTIONS: Api2MappingsActions,
        PathValues.API_2_MAPPINGS_ACTIONS_MAPPING_ACTION_VALUE_VALUES: Api2MappingsActionsMappingActionValueValues,
        PathValues.API_2_MAPPINGS_SORT: Api2MappingsSort,
        PathValues.API_2_APPS: Api2Apps,
        PathValues.API_2_APPS_APP_ID: Api2AppsAppId,
        PathValues.API_2_APPS_APP_ID_PARAMETERS_PARAMETER_ID: Api2AppsAppIdParametersParameterId,
        PathValues.API_2_APPS_APP_ID_USERS: Api2AppsAppIdUsers,
        PathValues.API_2_APPS_APP_ID_RULES: Api2AppsAppIdRules,
        PathValues.API_2_APPS_APP_ID_RULES_RULE_ID: Api2AppsAppIdRulesRuleId,
        PathValues.API_2_APPS_APP_ID_RULES_CONDITIONS: Api2AppsAppIdRulesConditions,
        PathValues.API_2_APPS_APP_ID_RULES_CONDITIONS_RULE_CONDITION_VALUE_OPERATORS: Api2AppsAppIdRulesConditionsRuleConditionValueOperators,
        PathValues.API_2_APPS_APP_ID_RULES_CONDITIONS_RULE_CONDITION_VALUE_VALUES: Api2AppsAppIdRulesConditionsRuleConditionValueValues,
        PathValues.API_2_APPS_APP_ID_RULES_ACTIONS: Api2AppsAppIdRulesActions,
        PathValues.API_2_APPS_APP_ID_RULES_ACTIONS_RULE_ACTION_VALUE_VALUES: Api2AppsAppIdRulesActionsRuleActionValueValues,
        PathValues.API_2_APPS_APP_ID_RULES_SORT: Api2AppsAppIdRulesSort,
        PathValues.API_2_CONNECTORS: Api2Connectors,
        PathValues.API_2_RISK_RULES: Api2RiskRules,
        PathValues.API_2_RISK_RULES_RULE_ID: Api2RiskRulesRuleId,
        PathValues.API_2_RISK_EVENTS: Api2RiskEvents,
        PathValues.API_2_RISK_SCORES: Api2RiskScores,
        PathValues.API_2_RISK_VERIFY: Api2RiskVerify,
        PathValues.API_2_MFA_USERS_USER_ID_REGISTRATIONS_REGISTRATION_ID: Api2MfaUsersUserIdRegistrationsRegistrationId,
        PathValues.API_2_MFA_USERS_USER_ID_REGISTRATIONS: Api2MfaUsersUserIdRegistrations,
        PathValues.API_2_MFA_USERS_USER_ID_DEVICES: Api2MfaUsersUserIdDevices,
        PathValues.API_2_MFA_USERS_USER_ID_DEVICES_DEVICE_ID: Api2MfaUsersUserIdDevicesDeviceId,
        PathValues.API_2_MFA_USERS_USER_ID_VERIFICATIONS_VERIFICATION_ID: Api2MfaUsersUserIdVerificationsVerificationId,
        PathValues.API_2_MFA_USERS_USER_ID_VERIFICATIONS: Api2MfaUsersUserIdVerifications,
        PathValues.API_2_MFA_USERS_USER_ID_FACTORS: Api2MfaUsersUserIdFactors,
        PathValues.API_2_MFA_USERS_USER_ID_MFA_TOKEN: Api2MfaUsersUserIdMfaToken,
        PathValues.API_2_ROLES: Api2Roles,
        PathValues.API_2_ROLES_ROLE_ID: Api2RolesRoleId,
        PathValues.API_2_ROLES_ROLE_ID_APPS: Api2RolesRoleIdApps,
        PathValues.API_2_ROLES_ROLE_ID_USERS: Api2RolesRoleIdUsers,
        PathValues.API_2_ROLES_ROLE_ID_ADMINS: Api2RolesRoleIdAdmins,
        PathValues.API_2_HOOKS: Api2Hooks,
        PathValues.API_2_HOOKS_HOOK_ID: Api2HooksHookId,
        PathValues.API_2_HOOKS_HOOK_ID_LOGS: Api2HooksHookIdLogs,
        PathValues.API_2_HOOKS_ENVS: Api2HooksEnvs,
        PathValues.API_2_HOOKS_ENVS_ENVVAR_ID: Api2HooksEnvsEnvvarId,
        PathValues.API_2_USERS: Api2Users,
        PathValues.API_2_USERS_USER_ID: Api2UsersUserId,
        PathValues.API_2_USERS_USER_ID_APPS: Api2UsersUserIdApps,
        PathValues.API_2_BRANDING_BRANDS: Api2BrandingBrands,
        PathValues.API_2_BRANDING_BRANDS_BRAND_ID: Api2BrandingBrandsBrandId,
        PathValues.API_2_BRANDING_BRANDS_BRAND_ID_TEMPLATES: Api2BrandingBrandsBrandIdTemplates,
        PathValues.API_2_BRANDING_BRANDS_BRAND_ID_TEMPLATES_TEMPLATE_ID: Api2BrandingBrandsBrandIdTemplatesTemplateId,
        PathValues.API_2_BRANDING_BRANDS_BRAND_ID_APPS: Api2BrandingBrandsBrandIdApps,
        PathValues.API_2_BRANDING_EMAIL_SETTINGS: Api2BrandingEmailSettings,
        PathValues.API_2_BRANDING_BRANDS_BRAND_ID_TEMPLATES_TEMPLATE_TYPE_LOCALE: Api2BrandingBrandsBrandIdTemplatesTemplateTypeLocale,
        PathValues.API_2_BRANDING_BRANDS_MASTER_TEMPLATES_TEMPLATE_TYPE: Api2BrandingBrandsMasterTemplatesTemplateType,
    }
)

path_to_api = PathToApi(
    {
        PathValues.AUTH_OAUTH2_V2_TOKEN: AuthOauth2V2Token,
        PathValues.AUTH_OAUTH2_REVOKE: AuthOauth2Revoke,
        PathValues.AUTH_RATE_LIMIT: AuthRateLimit,
        PathValues.API_2_API_AUTHORIZATIONS: Api2ApiAuthorizations,
        PathValues.API_2_API_AUTHORIZATIONS_API_AUTH_ID: Api2ApiAuthorizationsApiAuthId,
        PathValues.API_2_API_AUTHORIZATIONS_API_AUTH_ID_SCOPES: Api2ApiAuthorizationsApiAuthIdScopes,
        PathValues.API_2_API_AUTHORIZATIONS_API_AUTH_ID_SCOPES_SCOPE_ID: Api2ApiAuthorizationsApiAuthIdScopesScopeId,
        PathValues.API_2_API_AUTHORIZATIONS_API_AUTH_ID_CLAIMS: Api2ApiAuthorizationsApiAuthIdClaims,
        PathValues.API_2_API_AUTHORIZATIONS_API_AUTH_ID_CLAIMS_CLAIM_ID: Api2ApiAuthorizationsApiAuthIdClaimsClaimId,
        PathValues.API_2_API_AUTHORIZATIONS_API_AUTH_ID_CLIENTS: Api2ApiAuthorizationsApiAuthIdClients,
        PathValues.API_2_API_AUTHORIZATIONS_API_AUTH_ID_CLIENTS_CLIENT_APP_ID: Api2ApiAuthorizationsApiAuthIdClientsClientAppId,
        PathValues.API_1_EVENTS: Api1Events,
        PathValues.API_1_EVENTS_EVENT_ID: Api1EventsEventId,
        PathValues.API_1_EVENTS_TYPES: Api1EventsTypes,
        PathValues.API_1_GROUPS: Api1Groups,
        PathValues.API_1_GROUPS_GROUP_ID: Api1GroupsGroupId,
        PathValues.API_1_INVITES_GET_INVITE_LINK: Api1InvitesGetInviteLink,
        PathValues.API_1_INVITES_SEND_INVITE_LINK: Api1InvitesSendInviteLink,
        PathValues.API_1_USERS: Api1Users,
        PathValues.API_1_USERS_USER_ID: Api1UsersUserId,
        PathValues.API_1_USERS_USER_ID_APPS: Api1UsersUserIdApps,
        PathValues.API_1_USERS_USER_ID_ROLES: Api1UsersUserIdRoles,
        PathValues.API_1_USERS_SET_PASSWORD_CLEAR_TEXT_USER_ID: Api1UsersSetPasswordClearTextUserId,
        PathValues.API_1_USERS_SET_PASSWORD_USING_SALT_USER_ID: Api1UsersSetPasswordUsingSaltUserId,
        PathValues.API_1_USERS_CUSTOM_ATTRIBUTES: Api1UsersCustomAttributes,
        PathValues.API_1_USERS_USER_ID_AUTH_FACTOR: Api1UsersUserIdAuthFactor,
        PathValues.API_1_USERS_USER_ID_LOGOUT: Api1UsersUserIdLogout,
        PathValues.API_1_USERS_USER_ID_LOCK_USER: Api1UsersUserIdLockUser,
        PathValues.API_1_USERS_USER_ID_OTP_DEVICES: Api1UsersUserIdOtpDevices,
        PathValues.API_1_USERS_USER_ID_MFA_TOKEN: Api1UsersUserIdMfaToken,
        PathValues.API_1_USERS_USER_ID_ADD_ROLES: Api1UsersUserIdAddRoles,
        PathValues.API_1_USERS_USER_ID_SET_STATE: Api1UsersUserIdSetState,
        PathValues.API_1_USERS_USER_ID_REMOVE_ROLES: Api1UsersUserIdRemoveRoles,
        PathValues.API_1_USERS_USER_ID_OTP_DEVICES_DEVICE_ID: Api1UsersUserIdOtpDevicesDeviceId,
        PathValues.API_1_USERS_USER_ID_OTP_DEVICES_DEVICE_ID_VERIFY: Api1UsersUserIdOtpDevicesDeviceIdVerify,
        PathValues.API_1_USERS_USER_ID_OTP_DEVICES_DEVICE_ID_TRIGGER: Api1UsersUserIdOtpDevicesDeviceIdTrigger,
        PathValues.API_1_PRIVILEGES: Api1Privileges,
        PathValues.API_1_PRIVILEGES_PRIVILEGE_ID: Api1PrivilegesPrivilegeId,
        PathValues.API_1_PRIVILEGES_PRIVILEGE_ID_ROLES: Api1PrivilegesPrivilegeIdRoles,
        PathValues.API_1_PRIVILEGES_PRIVILEGE_ID_ROLES_ROLE_ID: Api1PrivilegesPrivilegeIdRolesRoleId,
        PathValues.API_1_PRIVILEGES_PRIVILEGE_ID_USERS: Api1PrivilegesPrivilegeIdUsers,
        PathValues.API_1_PRIVILEGES_PRIVILEGE_ID_USERS_USER_ID: Api1PrivilegesPrivilegeIdUsersUserId,
        PathValues.API_1_ROLES: Api1Roles,
        PathValues.API_1_ROLES_ROLE_ID: Api1RolesRoleId,
        PathValues.API_1_SAML_ASSERTION: Api1SamlAssertion,
        PathValues.API_1_SAML_ASSERTION_VERIFY_FACTOR: Api1SamlAssertionVerifyFactor,
        PathValues.API_2_SAML_ASSERTION: Api2SamlAssertion,
        PathValues.API_2_SAML_ASSERTION_VERIFY_FACTOR: Api2SamlAssertionVerifyFactor,
        PathValues.API_2_MAPPINGS: Api2Mappings,
        PathValues.API_2_MAPPINGS_MAPPING_ID: Api2MappingsMappingId,
        PathValues.API_2_MAPPINGS_CONDITIONS: Api2MappingsConditions,
        PathValues.API_2_MAPPINGS_CONDITIONS_MAPPING_CONDITION_VALUE_OPERATORS: Api2MappingsConditionsMappingConditionValueOperators,
        PathValues.API_2_MAPPINGS_CONDITIONS_MAPPING_CONDITION_VALUE_VALUES: Api2MappingsConditionsMappingConditionValueValues,
        PathValues.API_2_MAPPINGS_ACTIONS: Api2MappingsActions,
        PathValues.API_2_MAPPINGS_ACTIONS_MAPPING_ACTION_VALUE_VALUES: Api2MappingsActionsMappingActionValueValues,
        PathValues.API_2_MAPPINGS_SORT: Api2MappingsSort,
        PathValues.API_2_APPS: Api2Apps,
        PathValues.API_2_APPS_APP_ID: Api2AppsAppId,
        PathValues.API_2_APPS_APP_ID_PARAMETERS_PARAMETER_ID: Api2AppsAppIdParametersParameterId,
        PathValues.API_2_APPS_APP_ID_USERS: Api2AppsAppIdUsers,
        PathValues.API_2_APPS_APP_ID_RULES: Api2AppsAppIdRules,
        PathValues.API_2_APPS_APP_ID_RULES_RULE_ID: Api2AppsAppIdRulesRuleId,
        PathValues.API_2_APPS_APP_ID_RULES_CONDITIONS: Api2AppsAppIdRulesConditions,
        PathValues.API_2_APPS_APP_ID_RULES_CONDITIONS_RULE_CONDITION_VALUE_OPERATORS: Api2AppsAppIdRulesConditionsRuleConditionValueOperators,
        PathValues.API_2_APPS_APP_ID_RULES_CONDITIONS_RULE_CONDITION_VALUE_VALUES: Api2AppsAppIdRulesConditionsRuleConditionValueValues,
        PathValues.API_2_APPS_APP_ID_RULES_ACTIONS: Api2AppsAppIdRulesActions,
        PathValues.API_2_APPS_APP_ID_RULES_ACTIONS_RULE_ACTION_VALUE_VALUES: Api2AppsAppIdRulesActionsRuleActionValueValues,
        PathValues.API_2_APPS_APP_ID_RULES_SORT: Api2AppsAppIdRulesSort,
        PathValues.API_2_CONNECTORS: Api2Connectors,
        PathValues.API_2_RISK_RULES: Api2RiskRules,
        PathValues.API_2_RISK_RULES_RULE_ID: Api2RiskRulesRuleId,
        PathValues.API_2_RISK_EVENTS: Api2RiskEvents,
        PathValues.API_2_RISK_SCORES: Api2RiskScores,
        PathValues.API_2_RISK_VERIFY: Api2RiskVerify,
        PathValues.API_2_MFA_USERS_USER_ID_REGISTRATIONS_REGISTRATION_ID: Api2MfaUsersUserIdRegistrationsRegistrationId,
        PathValues.API_2_MFA_USERS_USER_ID_REGISTRATIONS: Api2MfaUsersUserIdRegistrations,
        PathValues.API_2_MFA_USERS_USER_ID_DEVICES: Api2MfaUsersUserIdDevices,
        PathValues.API_2_MFA_USERS_USER_ID_DEVICES_DEVICE_ID: Api2MfaUsersUserIdDevicesDeviceId,
        PathValues.API_2_MFA_USERS_USER_ID_VERIFICATIONS_VERIFICATION_ID: Api2MfaUsersUserIdVerificationsVerificationId,
        PathValues.API_2_MFA_USERS_USER_ID_VERIFICATIONS: Api2MfaUsersUserIdVerifications,
        PathValues.API_2_MFA_USERS_USER_ID_FACTORS: Api2MfaUsersUserIdFactors,
        PathValues.API_2_MFA_USERS_USER_ID_MFA_TOKEN: Api2MfaUsersUserIdMfaToken,
        PathValues.API_2_ROLES: Api2Roles,
        PathValues.API_2_ROLES_ROLE_ID: Api2RolesRoleId,
        PathValues.API_2_ROLES_ROLE_ID_APPS: Api2RolesRoleIdApps,
        PathValues.API_2_ROLES_ROLE_ID_USERS: Api2RolesRoleIdUsers,
        PathValues.API_2_ROLES_ROLE_ID_ADMINS: Api2RolesRoleIdAdmins,
        PathValues.API_2_HOOKS: Api2Hooks,
        PathValues.API_2_HOOKS_HOOK_ID: Api2HooksHookId,
        PathValues.API_2_HOOKS_HOOK_ID_LOGS: Api2HooksHookIdLogs,
        PathValues.API_2_HOOKS_ENVS: Api2HooksEnvs,
        PathValues.API_2_HOOKS_ENVS_ENVVAR_ID: Api2HooksEnvsEnvvarId,
        PathValues.API_2_USERS: Api2Users,
        PathValues.API_2_USERS_USER_ID: Api2UsersUserId,
        PathValues.API_2_USERS_USER_ID_APPS: Api2UsersUserIdApps,
        PathValues.API_2_BRANDING_BRANDS: Api2BrandingBrands,
        PathValues.API_2_BRANDING_BRANDS_BRAND_ID: Api2BrandingBrandsBrandId,
        PathValues.API_2_BRANDING_BRANDS_BRAND_ID_TEMPLATES: Api2BrandingBrandsBrandIdTemplates,
        PathValues.API_2_BRANDING_BRANDS_BRAND_ID_TEMPLATES_TEMPLATE_ID: Api2BrandingBrandsBrandIdTemplatesTemplateId,
        PathValues.API_2_BRANDING_BRANDS_BRAND_ID_APPS: Api2BrandingBrandsBrandIdApps,
        PathValues.API_2_BRANDING_EMAIL_SETTINGS: Api2BrandingEmailSettings,
        PathValues.API_2_BRANDING_BRANDS_BRAND_ID_TEMPLATES_TEMPLATE_TYPE_LOCALE: Api2BrandingBrandsBrandIdTemplatesTemplateTypeLocale,
        PathValues.API_2_BRANDING_BRANDS_MASTER_TEMPLATES_TEMPLATE_TYPE: Api2BrandingBrandsMasterTemplatesTemplateType,
    }
)



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from onelogin import schemas  # noqa: F401


class RequestBrand(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "name",
        }
        
        class properties:
            name = schemas.StrSchema
            enabled = schemas.BoolSchema
            custom_support_enabled = schemas.BoolSchema
            custom_color = schemas.StrSchema
            custom_accent_color = schemas.StrSchema
            custom_masking_color = schemas.StrSchema
            custom_masking_opacity = schemas.IntSchema
            enable_custom_label_for_login_screen = schemas.BoolSchema
            custom_label_text_for_login_screen = schemas.StrSchema
            login_instruction_title = schemas.StrSchema
            login_instruction = schemas.StrSchema
            hide_onelogin_footer = schemas.BoolSchema
            mfa_enrollment_message = schemas.StrSchema
            background = schemas.StrSchema
            logo = schemas.StrSchema
            __annotations__ = {
                "name": name,
                "enabled": enabled,
                "custom_support_enabled": custom_support_enabled,
                "custom_color": custom_color,
                "custom_accent_color": custom_accent_color,
                "custom_masking_color": custom_masking_color,
                "custom_masking_opacity": custom_masking_opacity,
                "enable_custom_label_for_login_screen": enable_custom_label_for_login_screen,
                "custom_label_text_for_login_screen": custom_label_text_for_login_screen,
                "login_instruction_title": login_instruction_title,
                "login_instruction": login_instruction,
                "hide_onelogin_footer": hide_onelogin_footer,
                "mfa_enrollment_message": mfa_enrollment_message,
                "background": background,
                "logo": logo,
            }
    
    name: MetaOapg.properties.name
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["enabled"]) -> MetaOapg.properties.enabled: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["custom_support_enabled"]) -> MetaOapg.properties.custom_support_enabled: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["custom_color"]) -> MetaOapg.properties.custom_color: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["custom_accent_color"]) -> MetaOapg.properties.custom_accent_color: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["custom_masking_color"]) -> MetaOapg.properties.custom_masking_color: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["custom_masking_opacity"]) -> MetaOapg.properties.custom_masking_opacity: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["enable_custom_label_for_login_screen"]) -> MetaOapg.properties.enable_custom_label_for_login_screen: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["custom_label_text_for_login_screen"]) -> MetaOapg.properties.custom_label_text_for_login_screen: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["login_instruction_title"]) -> MetaOapg.properties.login_instruction_title: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["login_instruction"]) -> MetaOapg.properties.login_instruction: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["hide_onelogin_footer"]) -> MetaOapg.properties.hide_onelogin_footer: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["mfa_enrollment_message"]) -> MetaOapg.properties.mfa_enrollment_message: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["background"]) -> MetaOapg.properties.background: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["logo"]) -> MetaOapg.properties.logo: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["name", "enabled", "custom_support_enabled", "custom_color", "custom_accent_color", "custom_masking_color", "custom_masking_opacity", "enable_custom_label_for_login_screen", "custom_label_text_for_login_screen", "login_instruction_title", "login_instruction", "hide_onelogin_footer", "mfa_enrollment_message", "background", "logo", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["enabled"]) -> typing.Union[MetaOapg.properties.enabled, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["custom_support_enabled"]) -> typing.Union[MetaOapg.properties.custom_support_enabled, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["custom_color"]) -> typing.Union[MetaOapg.properties.custom_color, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["custom_accent_color"]) -> typing.Union[MetaOapg.properties.custom_accent_color, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["custom_masking_color"]) -> typing.Union[MetaOapg.properties.custom_masking_color, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["custom_masking_opacity"]) -> typing.Union[MetaOapg.properties.custom_masking_opacity, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["enable_custom_label_for_login_screen"]) -> typing.Union[MetaOapg.properties.enable_custom_label_for_login_screen, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["custom_label_text_for_login_screen"]) -> typing.Union[MetaOapg.properties.custom_label_text_for_login_screen, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["login_instruction_title"]) -> typing.Union[MetaOapg.properties.login_instruction_title, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["login_instruction"]) -> typing.Union[MetaOapg.properties.login_instruction, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["hide_onelogin_footer"]) -> typing.Union[MetaOapg.properties.hide_onelogin_footer, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["mfa_enrollment_message"]) -> typing.Union[MetaOapg.properties.mfa_enrollment_message, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["background"]) -> typing.Union[MetaOapg.properties.background, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["logo"]) -> typing.Union[MetaOapg.properties.logo, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["name", "enabled", "custom_support_enabled", "custom_color", "custom_accent_color", "custom_masking_color", "custom_masking_opacity", "enable_custom_label_for_login_screen", "custom_label_text_for_login_screen", "login_instruction_title", "login_instruction", "hide_onelogin_footer", "mfa_enrollment_message", "background", "logo", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        name: typing.Union[MetaOapg.properties.name, str, ],
        enabled: typing.Union[MetaOapg.properties.enabled, bool, schemas.Unset] = schemas.unset,
        custom_support_enabled: typing.Union[MetaOapg.properties.custom_support_enabled, bool, schemas.Unset] = schemas.unset,
        custom_color: typing.Union[MetaOapg.properties.custom_color, str, schemas.Unset] = schemas.unset,
        custom_accent_color: typing.Union[MetaOapg.properties.custom_accent_color, str, schemas.Unset] = schemas.unset,
        custom_masking_color: typing.Union[MetaOapg.properties.custom_masking_color, str, schemas.Unset] = schemas.unset,
        custom_masking_opacity: typing.Union[MetaOapg.properties.custom_masking_opacity, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        enable_custom_label_for_login_screen: typing.Union[MetaOapg.properties.enable_custom_label_for_login_screen, bool, schemas.Unset] = schemas.unset,
        custom_label_text_for_login_screen: typing.Union[MetaOapg.properties.custom_label_text_for_login_screen, str, schemas.Unset] = schemas.unset,
        login_instruction_title: typing.Union[MetaOapg.properties.login_instruction_title, str, schemas.Unset] = schemas.unset,
        login_instruction: typing.Union[MetaOapg.properties.login_instruction, str, schemas.Unset] = schemas.unset,
        hide_onelogin_footer: typing.Union[MetaOapg.properties.hide_onelogin_footer, bool, schemas.Unset] = schemas.unset,
        mfa_enrollment_message: typing.Union[MetaOapg.properties.mfa_enrollment_message, str, schemas.Unset] = schemas.unset,
        background: typing.Union[MetaOapg.properties.background, str, schemas.Unset] = schemas.unset,
        logo: typing.Union[MetaOapg.properties.logo, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'RequestBrand':
        return super().__new__(
            cls,
            *_args,
            name=name,
            enabled=enabled,
            custom_support_enabled=custom_support_enabled,
            custom_color=custom_color,
            custom_accent_color=custom_accent_color,
            custom_masking_color=custom_masking_color,
            custom_masking_opacity=custom_masking_opacity,
            enable_custom_label_for_login_screen=enable_custom_label_for_login_screen,
            custom_label_text_for_login_screen=custom_label_text_for_login_screen,
            login_instruction_title=login_instruction_title,
            login_instruction=login_instruction,
            hide_onelogin_footer=hide_onelogin_footer,
            mfa_enrollment_message=mfa_enrollment_message,
            background=background,
            logo=logo,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_2_mfa_users_user_id_verifications.post import CreateDeviceVerification
from onelogin.paths.api_2_mfa_users_user_id_registrations.post import CreateFactorRegistration
from onelogin.paths.api_2_mfa_users_user_id_devices_device_id.delete import DeleteEnrolledFactor
from onelogin.paths.api_2_mfa_users_user_id_mfa_token.post import GenerateOtp
from onelogin.paths.api_2_mfa_users_user_id_factors.get import GetAuthFactors
from onelogin.paths.api_2_mfa_users_user_id_devices.get import GetAuthenticationDevices
from onelogin.paths.api_2_mfa_users_user_id_registrations_registration_id.get import GetUserRegistration
from onelogin.paths.api_2_mfa_users_user_id_verifications_verification_id.get import GetUserVerification
from onelogin.paths.api_2_mfa_users_user_id_registrations_registration_id.put import VerifyUserRegistration
from onelogin.paths.api_2_mfa_users_user_id_verifications_verification_id.put import VerifyUserVerification


class MultiFactorAuthenticationApi(
    CreateDeviceVerification,
    CreateFactorRegistration,
    DeleteEnrolledFactor,
    GenerateOtp,
    GetAuthFactors,
    GetAuthenticationDevices,
    GetUserRegistration,
    GetUserVerification,
    VerifyUserRegistration,
    VerifyUserVerification,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



from onelogin.paths.api_2_mfa_users_user_id_verifications_verification_id.get import ApiForget
from onelogin.paths.api_2_mfa_users_user_id_verifications_verification_id.put import ApiForput


class Api2MfaUsersUserIdVerificationsVerificationId(
    ApiForget,
    ApiForput,
):
    pass



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_2_branding_brands_brand_id_templates.post import CreateMessageTemplate
from onelogin.paths.api_2_branding_brands_brand_id_templates_template_id.delete import DeleteMessageTemplate
from onelogin.paths.api_2_branding_brands_master_templates_template_type.get import GetMasterByType
from onelogin.paths.api_2_branding_brands_brand_id_templates_template_id.get import GetMessageTemplateById
from onelogin.paths.api_2_branding_brands_brand_id_templates_template_type_locale.get import GetTemplateByLocale
from onelogin.paths.api_2_branding_brands_brand_id_templates.get import ListMessageTemplates
from onelogin.paths.api_2_branding_brands_brand_id_templates_template_id.put import UpdateMessageTemplateById
from onelogin.paths.api_2_branding_brands_brand_id_templates_template_type_locale.put import UpdateTemplateByLocale


class BrandingServiceTemplatesApi(
    CreateMessageTemplate,
    DeleteMessageTemplate,
    GetMasterByType,
    GetMessageTemplateById,
    GetTemplateByLocale,
    ListMessageTemplates,
    UpdateMessageTemplateById,
    UpdateTemplateByLocale,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_1_saml_assertion.post import GenerateSamlAssert
from onelogin.paths.api_2_saml_assertion.post import GenerateSamlAssert2
from onelogin.paths.api_1_saml_assertion_verify_factor.post import VerFactorSaml
from onelogin.paths.api_2_saml_assertion_verify_factor.post import VerFactorSaml2


class SAMLAssertionsApi(
    GenerateSamlAssert,
    GenerateSamlAssert2,
    VerFactorSaml,
    VerFactorSaml2,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_2_branding_brands.post import CreateBrand
from onelogin.paths.api_2_branding_brands_brand_id.delete import DeleteBrand
from onelogin.paths.api_2_branding_brands_brand_id.get import GetBrand
from onelogin.paths.api_2_branding_brands_brand_id_apps.get import GetBrandApps
from onelogin.paths.api_2_branding_brands.get import ListBrands
from onelogin.paths.api_2_branding_brands_brand_id.put import UpdateBrand


class BrandingServiceApi(
    CreateBrand,
    DeleteBrand,
    GetBrand,
    GetBrandApps,
    ListBrands,
    UpdateBrand,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_1_privileges_privilege_id_roles.post import AddPrivilegeToRole
from onelogin.paths.api_1_privileges_privilege_id_users.post import AssignUsersToPrivilege
from onelogin.paths.api_1_privileges.post import CreatePrivilege
from onelogin.paths.api_1_privileges_privilege_id.delete import DeletePrivilege
from onelogin.paths.api_1_privileges_privilege_id_roles_role_id.delete import DeleteRoleFromPrivilege
from onelogin.paths.api_1_privileges_privilege_id_users.get import GetAssignedUser
from onelogin.paths.api_1_privileges_privilege_id.get import GetPrivilege
from onelogin.paths.api_1_privileges_privilege_id_roles.get import ListPrivilegeRoles
from onelogin.paths.api_1_privileges.get import ListPrivileges
from onelogin.paths.api_1_privileges_privilege_id_users_user_id.delete import RemoveUserFromPrivilege
from onelogin.paths.api_1_privileges_privilege_id.put import UpdatePrivilege


class PrivilegesApi(
    AddPrivilegeToRole,
    AssignUsersToPrivilege,
    CreatePrivilege,
    DeletePrivilege,
    DeleteRoleFromPrivilege,
    GetAssignedUser,
    GetPrivilege,
    ListPrivilegeRoles,
    ListPrivileges,
    RemoveUserFromPrivilege,
    UpdatePrivilege,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from onelogin import schemas  # noqa: F401


class MessageTemplate(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "template",
            "locale",
            "type",
        }
        
        class properties:
            
            
            class type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "email_forgot_password": "EMAIL_FORGOT_PASSWORD",
                        "email_code_registration": "EMAIL_CODE_REGISTRATION",
                        "email_code_login_verification": "EMAIL_CODE_LOGIN_VERIFICATION",
                        "email_code_app_verification": "EMAIL_CODE_APP_VERIFICATION",
                        "email_code_pw_reset_verification": "EMAIL_CODE_PW_RESET_VERIFICATION",
                        "email_magiclink_registration": "EMAIL_MAGICLINK_REGISTRATION",
                        "email_magiclink_login_verification": "EMAIL_MAGICLINK_LOGIN_VERIFICATION",
                        "email_magiclink_app_verification": "EMAIL_MAGICLINK_APP_VERIFICATION",
                        "email_magiclink_pw_reset_verification": "EMAIL_MAGICLINK_PW_RESET_VERIFICATION",
                        "sms_registration": "SMS_REGISTRATION",
                        "sms_login_verification": "SMS_LOGIN_VERIFICATION",
                        "sms_app_verification": "SMS_APP_VERIFICATION",
                        "sms_pw_reset_verification": "SMS_PW_RESET_VERIFICATION",
                    }
                
                @schemas.classproperty
                def EMAIL_FORGOT_PASSWORD(cls):
                    return cls("email_forgot_password")
                
                @schemas.classproperty
                def EMAIL_CODE_REGISTRATION(cls):
                    return cls("email_code_registration")
                
                @schemas.classproperty
                def EMAIL_CODE_LOGIN_VERIFICATION(cls):
                    return cls("email_code_login_verification")
                
                @schemas.classproperty
                def EMAIL_CODE_APP_VERIFICATION(cls):
                    return cls("email_code_app_verification")
                
                @schemas.classproperty
                def EMAIL_CODE_PW_RESET_VERIFICATION(cls):
                    return cls("email_code_pw_reset_verification")
                
                @schemas.classproperty
                def EMAIL_MAGICLINK_REGISTRATION(cls):
                    return cls("email_magiclink_registration")
                
                @schemas.classproperty
                def EMAIL_MAGICLINK_LOGIN_VERIFICATION(cls):
                    return cls("email_magiclink_login_verification")
                
                @schemas.classproperty
                def EMAIL_MAGICLINK_APP_VERIFICATION(cls):
                    return cls("email_magiclink_app_verification")
                
                @schemas.classproperty
                def EMAIL_MAGICLINK_PW_RESET_VERIFICATION(cls):
                    return cls("email_magiclink_pw_reset_verification")
                
                @schemas.classproperty
                def SMS_REGISTRATION(cls):
                    return cls("sms_registration")
                
                @schemas.classproperty
                def SMS_LOGIN_VERIFICATION(cls):
                    return cls("sms_login_verification")
                
                @schemas.classproperty
                def SMS_APP_VERIFICATION(cls):
                    return cls("sms_app_verification")
                
                @schemas.classproperty
                def SMS_PW_RESET_VERIFICATION(cls):
                    return cls("sms_pw_reset_verification")
            
            
            class locale(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    regex=[{
                        'pattern': r'^[a-z]{2}$',  # noqa: E501
                    }]
            
            
            class template(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    
                    class one_of_0(
                        schemas.DictSchema
                    ):
                    
                    
                        class MetaOapg:
                            required = {
                                "plain",
                                "subject",
                                "html",
                            }
                            
                            class properties:
                                subject = schemas.StrSchema
                                html = schemas.StrSchema
                                plain = schemas.StrSchema
                                __annotations__ = {
                                    "subject": subject,
                                    "html": html,
                                    "plain": plain,
                                }
                        
                        plain: MetaOapg.properties.plain
                        subject: MetaOapg.properties.subject
                        html: MetaOapg.properties.html
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["subject"]) -> MetaOapg.properties.subject: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["html"]) -> MetaOapg.properties.html: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["plain"]) -> MetaOapg.properties.plain: ...
                        
                        @typing.overload
                        def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                        
                        def __getitem__(self, name: typing.Union[typing_extensions.Literal["subject", "html", "plain", ], str]):
                            # dict_instance[name] accessor
                            return super().__getitem__(name)
                        
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["subject"]) -> MetaOapg.properties.subject: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["html"]) -> MetaOapg.properties.html: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["plain"]) -> MetaOapg.properties.plain: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                        
                        def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["subject", "html", "plain", ], str]):
                            return super().get_item_oapg(name)
                        
                    
                        def __new__(
                            cls,
                            *_args: typing.Union[dict, frozendict.frozendict, ],
                            plain: typing.Union[MetaOapg.properties.plain, str, ],
                            subject: typing.Union[MetaOapg.properties.subject, str, ],
                            html: typing.Union[MetaOapg.properties.html, str, ],
                            _configuration: typing.Optional[schemas.Configuration] = None,
                            **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                        ) -> 'one_of_0':
                            return super().__new__(
                                cls,
                                *_args,
                                plain=plain,
                                subject=subject,
                                html=html,
                                _configuration=_configuration,
                                **kwargs,
                            )
                    
                    
                    class one_of_1(
                        schemas.DictSchema
                    ):
                    
                    
                        class MetaOapg:
                            required = {
                                "message",
                            }
                            
                            class properties:
                                
                                
                                class message(
                                    schemas.StrSchema
                                ):
                                
                                
                                    class MetaOapg:
                                        max_length = 160
                                __annotations__ = {
                                    "message": message,
                                }
                        
                        message: MetaOapg.properties.message
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["message"]) -> MetaOapg.properties.message: ...
                        
                        @typing.overload
                        def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                        
                        def __getitem__(self, name: typing.Union[typing_extensions.Literal["message", ], str]):
                            # dict_instance[name] accessor
                            return super().__getitem__(name)
                        
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["message"]) -> MetaOapg.properties.message: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                        
                        def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["message", ], str]):
                            return super().get_item_oapg(name)
                        
                    
                        def __new__(
                            cls,
                            *_args: typing.Union[dict, frozendict.frozendict, ],
                            message: typing.Union[MetaOapg.properties.message, str, ],
                            _configuration: typing.Optional[schemas.Configuration] = None,
                            **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                        ) -> 'one_of_1':
                            return super().__new__(
                                cls,
                                *_args,
                                message=message,
                                _configuration=_configuration,
                                **kwargs,
                            )
                    
                    @classmethod
                    @functools.lru_cache()
                    def one_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            cls.one_of_0,
                            cls.one_of_1,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'template':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            id = schemas.IntSchema
            account_id = schemas.IntSchema
            template_class = schemas.StrSchema
            updated_at = schemas.StrSchema
            brand_id = schemas.IntSchema
            __annotations__ = {
                "type": type,
                "locale": locale,
                "template": template,
                "id": id,
                "account_id": account_id,
                "template_class": template_class,
                "updated_at": updated_at,
                "brand_id": brand_id,
            }
    
    template: MetaOapg.properties.template
    locale: MetaOapg.properties.locale
    type: MetaOapg.properties.type
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["locale"]) -> MetaOapg.properties.locale: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["template"]) -> MetaOapg.properties.template: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["account_id"]) -> MetaOapg.properties.account_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["template_class"]) -> MetaOapg.properties.template_class: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["updated_at"]) -> MetaOapg.properties.updated_at: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["brand_id"]) -> MetaOapg.properties.brand_id: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["type", "locale", "template", "id", "account_id", "template_class", "updated_at", "brand_id", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["locale"]) -> MetaOapg.properties.locale: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["template"]) -> MetaOapg.properties.template: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["account_id"]) -> typing.Union[MetaOapg.properties.account_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["template_class"]) -> typing.Union[MetaOapg.properties.template_class, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["updated_at"]) -> typing.Union[MetaOapg.properties.updated_at, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["brand_id"]) -> typing.Union[MetaOapg.properties.brand_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["type", "locale", "template", "id", "account_id", "template_class", "updated_at", "brand_id", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        template: typing.Union[MetaOapg.properties.template, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        locale: typing.Union[MetaOapg.properties.locale, str, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        id: typing.Union[MetaOapg.properties.id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        account_id: typing.Union[MetaOapg.properties.account_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        template_class: typing.Union[MetaOapg.properties.template_class, str, schemas.Unset] = schemas.unset,
        updated_at: typing.Union[MetaOapg.properties.updated_at, str, schemas.Unset] = schemas.unset,
        brand_id: typing.Union[MetaOapg.properties.brand_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'MessageTemplate':
        return super().__new__(
            cls,
            *_args,
            template=template,
            locale=locale,
            type=type,
            id=id,
            account_id=account_id,
            template_class=template_class,
            updated_at=updated_at,
            brand_id=brand_id,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

# flake8: noqa

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

__version__ = "3.1.6"

# import ApiClient
from onelogin.api_client import ApiClient

# import Configuration
from onelogin.configuration import Configuration

# import exceptions
from onelogin.exceptions import OpenApiException
from onelogin.exceptions import ApiAttributeError
from onelogin.exceptions import ApiTypeError
from onelogin.exceptions import ApiValueError
from onelogin.exceptions import ApiKeyError
from onelogin.exceptions import ApiException



from onelogin.paths.api_2_risk_rules_rule_id.get import ApiForget
from onelogin.paths.api_2_risk_rules_rule_id.put import ApiForput
from onelogin.paths.api_2_risk_rules_rule_id.delete import ApiFordelete


class Api2RiskRulesRuleId(
    ApiForget,
    ApiForput,
    ApiFordelete,
):
    pass



# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from onelogin import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from onelogin import schemas  # noqa: F401

from onelogin.model.event import Event
from onelogin.model.error import Error

from . import path

# Query params


class EventTypeIdSchema(
    schemas.ListSchema
):


    class MetaOapg:
        items = schemas.IntSchema

    def __new__(
        cls,
        _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, decimal.Decimal, int, ]], typing.List[typing.Union[MetaOapg.items, decimal.Decimal, int, ]]],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'EventTypeIdSchema':
        return super().__new__(
            cls,
            _arg,
            _configuration=_configuration,
        )

    def __getitem__(self, i: int) -> MetaOapg.items:
        return super().__getitem__(i)
ClientIdSchema = schemas.IntSchema
DirectoryIdSchema = schemas.IntSchema
IdSchema = schemas.IntSchema
CreatedAtSchema = schemas.StrSchema
ResolutionSchema = schemas.StrSchema
SinceSchema = schemas.StrSchema
UntilSchema = schemas.StrSchema
UserIdSchema = schemas.IntSchema
RequestRequiredQueryParams = typing_extensions.TypedDict(
    'RequestRequiredQueryParams',
    {
    }
)
RequestOptionalQueryParams = typing_extensions.TypedDict(
    'RequestOptionalQueryParams',
    {
        'event_type_id': typing.Union[EventTypeIdSchema, list, tuple, ],
        'client_id': typing.Union[ClientIdSchema, decimal.Decimal, int, ],
        'directory_id': typing.Union[DirectoryIdSchema, decimal.Decimal, int, ],
        'id': typing.Union[IdSchema, decimal.Decimal, int, ],
        'created_at': typing.Union[CreatedAtSchema, str, ],
        'resolution': typing.Union[ResolutionSchema, str, ],
        'since': typing.Union[SinceSchema, str, ],
        'until': typing.Union[UntilSchema, str, ],
        'user_id': typing.Union[UserIdSchema, decimal.Decimal, int, ],
    },
    total=False
)


class RequestQueryParams(RequestRequiredQueryParams, RequestOptionalQueryParams):
    pass


request_query_event_type_id = api_client.QueryParameter(
    name="event_type_id",
    style=api_client.ParameterStyle.FORM,
    schema=EventTypeIdSchema,
    explode=True,
)
request_query_client_id = api_client.QueryParameter(
    name="client_id",
    style=api_client.ParameterStyle.FORM,
    schema=ClientIdSchema,
    explode=True,
)
request_query_directory_id = api_client.QueryParameter(
    name="directory_id",
    style=api_client.ParameterStyle.FORM,
    schema=DirectoryIdSchema,
    explode=True,
)
request_query_id = api_client.QueryParameter(
    name="id",
    style=api_client.ParameterStyle.FORM,
    schema=IdSchema,
    explode=True,
)
request_query_created_at = api_client.QueryParameter(
    name="created_at",
    style=api_client.ParameterStyle.FORM,
    schema=CreatedAtSchema,
    explode=True,
)
request_query_resolution = api_client.QueryParameter(
    name="resolution",
    style=api_client.ParameterStyle.FORM,
    schema=ResolutionSchema,
    explode=True,
)
request_query_since = api_client.QueryParameter(
    name="since",
    style=api_client.ParameterStyle.FORM,
    schema=SinceSchema,
    explode=True,
)
request_query_until = api_client.QueryParameter(
    name="until",
    style=api_client.ParameterStyle.FORM,
    schema=UntilSchema,
    explode=True,
)
request_query_user_id = api_client.QueryParameter(
    name="user_id",
    style=api_client.ParameterStyle.FORM,
    schema=UserIdSchema,
    explode=True,
)
_auth = [
    'OAuth2',
]


class SchemaFor200ResponseBodyApplicationJson(
    schemas.DictSchema
):


    class MetaOapg:
        
        class properties:
        
            @staticmethod
            def status() -> typing.Type['Error']:
                return Error
            
            
            class pagination(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    
                    class properties:
                        before_cursor = schemas.StrSchema
                        after_cursor = schemas.StrSchema
                        previous_link = schemas.StrSchema
                        next_link = schemas.StrSchema
                        __annotations__ = {
                            "before_cursor": before_cursor,
                            "after_cursor": after_cursor,
                            "previous_link": previous_link,
                            "next_link": next_link,
                        }
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["before_cursor"]) -> MetaOapg.properties.before_cursor: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["after_cursor"]) -> MetaOapg.properties.after_cursor: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["previous_link"]) -> MetaOapg.properties.previous_link: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["next_link"]) -> MetaOapg.properties.next_link: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["before_cursor", "after_cursor", "previous_link", "next_link", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["before_cursor"]) -> typing.Union[MetaOapg.properties.before_cursor, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["after_cursor"]) -> typing.Union[MetaOapg.properties.after_cursor, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["previous_link"]) -> typing.Union[MetaOapg.properties.previous_link, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["next_link"]) -> typing.Union[MetaOapg.properties.next_link, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["before_cursor", "after_cursor", "previous_link", "next_link", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, ],
                    before_cursor: typing.Union[MetaOapg.properties.before_cursor, str, schemas.Unset] = schemas.unset,
                    after_cursor: typing.Union[MetaOapg.properties.after_cursor, str, schemas.Unset] = schemas.unset,
                    previous_link: typing.Union[MetaOapg.properties.previous_link, str, schemas.Unset] = schemas.unset,
                    next_link: typing.Union[MetaOapg.properties.next_link, str, schemas.Unset] = schemas.unset,
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'pagination':
                    return super().__new__(
                        cls,
                        *_args,
                        before_cursor=before_cursor,
                        after_cursor=after_cursor,
                        previous_link=previous_link,
                        next_link=next_link,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class data(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['Event']:
                        return Event
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['Event'], typing.List['Event']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'data':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'Event':
                    return super().__getitem__(i)
            __annotations__ = {
                "status": status,
                "pagination": pagination,
                "data": data,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> 'Error': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["pagination"]) -> MetaOapg.properties.pagination: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["data"]) -> MetaOapg.properties.data: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["status", "pagination", "data", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> typing.Union['Error', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["pagination"]) -> typing.Union[MetaOapg.properties.pagination, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["data"]) -> typing.Union[MetaOapg.properties.data, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["status", "pagination", "data", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        status: typing.Union['Error', schemas.Unset] = schemas.unset,
        pagination: typing.Union[MetaOapg.properties.pagination, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        data: typing.Union[MetaOapg.properties.data, list, tuple, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SchemaFor200ResponseBodyApplicationJson':
        return super().__new__(
            cls,
            *_args,
            status=status,
            pagination=pagination,
            data=data,
            _configuration=_configuration,
            **kwargs,
        )


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor200ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationJson),
    },
)
SchemaFor400ResponseBodyApplicationJson = Error


@dataclass
class ApiResponseFor400(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor400ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_400 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor400,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor400ResponseBodyApplicationJson),
    },
)
SchemaFor401ResponseBodyApplicationJson = Error


@dataclass
class ApiResponseFor401(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor401ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_401 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor401,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor401ResponseBodyApplicationJson),
    },
)
_status_code_to_response = {
    '200': _response_for_200,
    '400': _response_for_400,
    '401': _response_for_401,
}
_all_accept_content_types = (
    'application/json',
)


class BaseApi(api_client.Api):
    @typing.overload
    def _get_events_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def _get_events_oapg(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def _get_events_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def _get_events_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        """
        Get Events
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        self._verify_typed_dict_inputs_oapg(RequestQueryParams, query_params)
        used_path = path.value

        prefix_separator_iterator = None
        for parameter in (
            request_query_event_type_id,
            request_query_client_id,
            request_query_directory_id,
            request_query_id,
            request_query_created_at,
            request_query_resolution,
            request_query_since,
            request_query_until,
            request_query_user_id,
        ):
            parameter_data = query_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            if prefix_separator_iterator is None:
                prefix_separator_iterator = parameter.get_prefix_separator_iterator()
            serialized_data = parameter.serialize(parameter_data, prefix_separator_iterator)
            for serialized_value in serialized_data.values():
                used_path += serialized_value

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        response = self.api_client.call_api(
            resource_path=used_path,
            method='get'.upper(),
            headers=_headers,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(
                status=response.status,
                reason=response.reason,
                api_response=api_response
            )

        return api_response


class GetEvents(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    @typing.overload
    def get_events(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def get_events(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def get_events(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def get_events(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._get_events_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForget(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    @typing.overload
    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def get(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._get_events_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )





# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

import unittest

import onelogin
from onelogin.model.clock_counter import ClockCounter
from onelogin import configuration


class TestClockCounter(unittest.TestCase):
    """ClockCounter unit test stubs"""
    _configuration = configuration.Configuration()


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_2_api_authorizations_api_auth_id_scopes.post import CreateScope
from onelogin.paths.api_2_api_authorizations_api_auth_id_scopes_scope_id.delete import DeleteScope
from onelogin.paths.api_2_api_authorizations_api_auth_id_scopes.get import GetScopes
from onelogin.paths.api_2_api_authorizations_api_auth_id_scopes_scope_id.put import UpdateScope


class APIAuthScopesApi(
    CreateScope,
    DeleteScope,
    GetScopes,
    UpdateScope,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_1_events_event_id.get import GetEventById
from onelogin.paths.api_1_events_types.get import GetEventTypes
from onelogin.paths.api_1_events.get import GetEvents


class EventsApi(
    GetEventById,
    GetEventTypes,
    GetEvents,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



import typing_extensions

from onelogin.apis.tags import TagValues
from onelogin.apis.tags.o_auth2_api import OAuth2Api
from onelogin.apis.tags.api_authorization_server_api import APIAuthorizationServerApi
from onelogin.apis.tags.api_auth_scopes_api import APIAuthScopesApi
from onelogin.apis.tags.api_auth_claims_api import APIAuthClaimsApi
from onelogin.apis.tags.api_auth_client_apps_api import APIAuthClientAppsApi
from onelogin.apis.tags.apps_api import AppsApi
from onelogin.apis.tags.app_rules_api import AppRulesApi
from onelogin.apis.tags.branding_service_api import BrandingServiceApi
from onelogin.apis.tags.branding_service_templates_api import BrandingServiceTemplatesApi
from onelogin.apis.tags.branding_service_smtp_api import BrandingServiceSMTPApi
from onelogin.apis.tags.events_api import EventsApi
from onelogin.apis.tags.groups_api import GroupsApi
from onelogin.apis.tags.invite_links_api import InviteLinksApi
from onelogin.apis.tags.multi_factor_authentication_api import MultiFactorAuthenticationApi
from onelogin.apis.tags.multi_factor_authentication_v1_api import MultiFactorAuthenticationV1Api
from onelogin.apis.tags.privileges_api import PrivilegesApi
from onelogin.apis.tags.roles_api import RolesApi
from onelogin.apis.tags.saml_assertions_api import SAMLAssertionsApi
from onelogin.apis.tags.users_v1_api import UsersV1Api
from onelogin.apis.tags.users_v2_api import UsersV2Api
from onelogin.apis.tags.user_mappings_api import UserMappingsApi
from onelogin.apis.tags.vigilance_ai_api import VigilanceAIApi
from onelogin.apis.tags.smart_hooks_api import SmartHooksApi

TagToApi = typing_extensions.TypedDict(
    'TagToApi',
    {
        TagValues.OAUTH2: OAuth2Api,
        TagValues.API_AUTHORIZATION_SERVER: APIAuthorizationServerApi,
        TagValues.API_AUTH_SCOPES: APIAuthScopesApi,
        TagValues.API_AUTH_CLAIMS: APIAuthClaimsApi,
        TagValues.API_AUTH_CLIENT_APPS: APIAuthClientAppsApi,
        TagValues.APPS: AppsApi,
        TagValues.APP_RULES: AppRulesApi,
        TagValues.BRANDING_SERVICE: BrandingServiceApi,
        TagValues.BRANDING_SERVICE_TEMPLATES: BrandingServiceTemplatesApi,
        TagValues.BRANDING_SERVICE_SMTP: BrandingServiceSMTPApi,
        TagValues.EVENTS: EventsApi,
        TagValues.GROUPS: GroupsApi,
        TagValues.INVITE_LINKS: InviteLinksApi,
        TagValues.MULTI_FACTOR_AUTHENTICATION: MultiFactorAuthenticationApi,
        TagValues.MULTI_FACTOR_AUTHENTICATION_V1: MultiFactorAuthenticationV1Api,
        TagValues.PRIVILEGES: PrivilegesApi,
        TagValues.ROLES: RolesApi,
        TagValues.SAML_ASSERTIONS: SAMLAssertionsApi,
        TagValues.USERS_V1: UsersV1Api,
        TagValues.USERS_V2: UsersV2Api,
        TagValues.USER_MAPPINGS: UserMappingsApi,
        TagValues.VIGILANCE_AI: VigilanceAIApi,
        TagValues.SMART_HOOKS: SmartHooksApi,
    }
)

tag_to_api = TagToApi(
    {
        TagValues.OAUTH2: OAuth2Api,
        TagValues.API_AUTHORIZATION_SERVER: APIAuthorizationServerApi,
        TagValues.API_AUTH_SCOPES: APIAuthScopesApi,
        TagValues.API_AUTH_CLAIMS: APIAuthClaimsApi,
        TagValues.API_AUTH_CLIENT_APPS: APIAuthClientAppsApi,
        TagValues.APPS: AppsApi,
        TagValues.APP_RULES: AppRulesApi,
        TagValues.BRANDING_SERVICE: BrandingServiceApi,
        TagValues.BRANDING_SERVICE_TEMPLATES: BrandingServiceTemplatesApi,
        TagValues.BRANDING_SERVICE_SMTP: BrandingServiceSMTPApi,
        TagValues.EVENTS: EventsApi,
        TagValues.GROUPS: GroupsApi,
        TagValues.INVITE_LINKS: InviteLinksApi,
        TagValues.MULTI_FACTOR_AUTHENTICATION: MultiFactorAuthenticationApi,
        TagValues.MULTI_FACTOR_AUTHENTICATION_V1: MultiFactorAuthenticationV1Api,
        TagValues.PRIVILEGES: PrivilegesApi,
        TagValues.ROLES: RolesApi,
        TagValues.SAML_ASSERTIONS: SAMLAssertionsApi,
        TagValues.USERS_V1: UsersV1Api,
        TagValues.USERS_V2: UsersV2Api,
        TagValues.USER_MAPPINGS: UserMappingsApi,
        TagValues.VIGILANCE_AI: VigilanceAIApi,
        TagValues.SMART_HOOKS: SmartHooksApi,
    }
)



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from onelogin import schemas  # noqa: F401


class TokenClaim(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
            id = schemas.IntSchema
            label = schemas.StrSchema
            user_attribute_mappings = schemas.StrSchema
            user_attribute_macros = schemas.StrSchema
            attribute_transformations = schemas.StrSchema
            skip_if_blank = schemas.BoolSchema
            
            
            class values(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'values':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            default_values = schemas.StrSchema
            provisioned_entitlements = schemas.BoolSchema
            __annotations__ = {
                "id": id,
                "label": label,
                "user_attribute_mappings": user_attribute_mappings,
                "user_attribute_macros": user_attribute_macros,
                "attribute_transformations": attribute_transformations,
                "skip_if_blank": skip_if_blank,
                "values": values,
                "default_values": default_values,
                "provisioned_entitlements": provisioned_entitlements,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["label"]) -> MetaOapg.properties.label: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["user_attribute_mappings"]) -> MetaOapg.properties.user_attribute_mappings: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["user_attribute_macros"]) -> MetaOapg.properties.user_attribute_macros: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["attribute_transformations"]) -> MetaOapg.properties.attribute_transformations: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["skip_if_blank"]) -> MetaOapg.properties.skip_if_blank: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["values"]) -> MetaOapg.properties.values: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["default_values"]) -> MetaOapg.properties.default_values: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["provisioned_entitlements"]) -> MetaOapg.properties.provisioned_entitlements: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "label", "user_attribute_mappings", "user_attribute_macros", "attribute_transformations", "skip_if_blank", "values", "default_values", "provisioned_entitlements", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["label"]) -> typing.Union[MetaOapg.properties.label, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["user_attribute_mappings"]) -> typing.Union[MetaOapg.properties.user_attribute_mappings, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["user_attribute_macros"]) -> typing.Union[MetaOapg.properties.user_attribute_macros, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["attribute_transformations"]) -> typing.Union[MetaOapg.properties.attribute_transformations, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["skip_if_blank"]) -> typing.Union[MetaOapg.properties.skip_if_blank, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["values"]) -> typing.Union[MetaOapg.properties.values, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["default_values"]) -> typing.Union[MetaOapg.properties.default_values, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["provisioned_entitlements"]) -> typing.Union[MetaOapg.properties.provisioned_entitlements, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "label", "user_attribute_mappings", "user_attribute_macros", "attribute_transformations", "skip_if_blank", "values", "default_values", "provisioned_entitlements", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        id: typing.Union[MetaOapg.properties.id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        label: typing.Union[MetaOapg.properties.label, str, schemas.Unset] = schemas.unset,
        user_attribute_mappings: typing.Union[MetaOapg.properties.user_attribute_mappings, str, schemas.Unset] = schemas.unset,
        user_attribute_macros: typing.Union[MetaOapg.properties.user_attribute_macros, str, schemas.Unset] = schemas.unset,
        attribute_transformations: typing.Union[MetaOapg.properties.attribute_transformations, str, schemas.Unset] = schemas.unset,
        skip_if_blank: typing.Union[MetaOapg.properties.skip_if_blank, bool, schemas.Unset] = schemas.unset,
        values: typing.Union[MetaOapg.properties.values, list, tuple, schemas.Unset] = schemas.unset,
        default_values: typing.Union[MetaOapg.properties.default_values, str, schemas.Unset] = schemas.unset,
        provisioned_entitlements: typing.Union[MetaOapg.properties.provisioned_entitlements, bool, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'TokenClaim':
        return super().__new__(
            cls,
            *_args,
            id=id,
            label=label,
            user_attribute_mappings=user_attribute_mappings,
            user_attribute_macros=user_attribute_macros,
            attribute_transformations=attribute_transformations,
            skip_if_blank=skip_if_blank,
            values=values,
            default_values=default_values,
            provisioned_entitlements=provisioned_entitlements,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from onelogin import schemas  # noqa: F401


class GenericApp(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
            id = schemas.IntSchema
            name = schemas.StrSchema
            visible = schemas.BoolSchema
            description = schemas.StrSchema
            notes = schemas.StrSchema
            icon_url = schemas.StrSchema
        
            @staticmethod
            def auth_method() -> typing.Type['AuthMethod']:
                return AuthMethod
            policy_id = schemas.IntSchema
            allow_assumed_signin = schemas.BoolSchema
            tab_id = schemas.IntSchema
            connector_id = schemas.IntSchema
            created_at = schemas.StrSchema
            updated_at = schemas.StrSchema
            
            
            class role_ids(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.IntSchema
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, decimal.Decimal, int, ]], typing.List[typing.Union[MetaOapg.items, decimal.Decimal, int, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'role_ids':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            
            
            class provisioning(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    
                    class properties:
                        enabled = schemas.BoolSchema
                        __annotations__ = {
                            "enabled": enabled,
                        }
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["enabled"]) -> MetaOapg.properties.enabled: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["enabled", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["enabled"]) -> typing.Union[MetaOapg.properties.enabled, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["enabled", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, ],
                    enabled: typing.Union[MetaOapg.properties.enabled, bool, schemas.Unset] = schemas.unset,
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'provisioning':
                    return super().__new__(
                        cls,
                        *_args,
                        enabled=enabled,
                        _configuration=_configuration,
                        **kwargs,
                    )
        
            @staticmethod
            def parameters() -> typing.Type['AppParameters']:
                return AppParameters
        
            @staticmethod
            def enforcement_point() -> typing.Type['EnforcementPoint']:
                return EnforcementPoint
            __annotations__ = {
                "id": id,
                "name": name,
                "visible": visible,
                "description": description,
                "notes": notes,
                "icon_url": icon_url,
                "auth_method": auth_method,
                "policy_id": policy_id,
                "allow_assumed_signin": allow_assumed_signin,
                "tab_id": tab_id,
                "connector_id": connector_id,
                "created_at": created_at,
                "updated_at": updated_at,
                "role_ids": role_ids,
                "provisioning": provisioning,
                "parameters": parameters,
                "enforcement_point": enforcement_point,
            }
        additional_properties = schemas.AnyTypeSchema
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["visible"]) -> MetaOapg.properties.visible: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["notes"]) -> MetaOapg.properties.notes: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["icon_url"]) -> MetaOapg.properties.icon_url: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["auth_method"]) -> 'AuthMethod': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["policy_id"]) -> MetaOapg.properties.policy_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["allow_assumed_signin"]) -> MetaOapg.properties.allow_assumed_signin: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tab_id"]) -> MetaOapg.properties.tab_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["connector_id"]) -> MetaOapg.properties.connector_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["created_at"]) -> MetaOapg.properties.created_at: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["updated_at"]) -> MetaOapg.properties.updated_at: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["role_ids"]) -> MetaOapg.properties.role_ids: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["provisioning"]) -> MetaOapg.properties.provisioning: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["parameters"]) -> 'AppParameters': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["enforcement_point"]) -> 'EnforcementPoint': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> MetaOapg.additional_properties: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id"], typing_extensions.Literal["name"], typing_extensions.Literal["visible"], typing_extensions.Literal["description"], typing_extensions.Literal["notes"], typing_extensions.Literal["icon_url"], typing_extensions.Literal["auth_method"], typing_extensions.Literal["policy_id"], typing_extensions.Literal["allow_assumed_signin"], typing_extensions.Literal["tab_id"], typing_extensions.Literal["connector_id"], typing_extensions.Literal["created_at"], typing_extensions.Literal["updated_at"], typing_extensions.Literal["role_ids"], typing_extensions.Literal["provisioning"], typing_extensions.Literal["parameters"], typing_extensions.Literal["enforcement_point"], str, ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> typing.Union[MetaOapg.properties.name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["visible"]) -> typing.Union[MetaOapg.properties.visible, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> typing.Union[MetaOapg.properties.description, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["notes"]) -> typing.Union[MetaOapg.properties.notes, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["icon_url"]) -> typing.Union[MetaOapg.properties.icon_url, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["auth_method"]) -> typing.Union['AuthMethod', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["policy_id"]) -> typing.Union[MetaOapg.properties.policy_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["allow_assumed_signin"]) -> typing.Union[MetaOapg.properties.allow_assumed_signin, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tab_id"]) -> typing.Union[MetaOapg.properties.tab_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["connector_id"]) -> typing.Union[MetaOapg.properties.connector_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["created_at"]) -> typing.Union[MetaOapg.properties.created_at, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["updated_at"]) -> typing.Union[MetaOapg.properties.updated_at, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["role_ids"]) -> typing.Union[MetaOapg.properties.role_ids, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["provisioning"]) -> typing.Union[MetaOapg.properties.provisioning, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["parameters"]) -> typing.Union['AppParameters', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["enforcement_point"]) -> typing.Union['EnforcementPoint', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[MetaOapg.additional_properties, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id"], typing_extensions.Literal["name"], typing_extensions.Literal["visible"], typing_extensions.Literal["description"], typing_extensions.Literal["notes"], typing_extensions.Literal["icon_url"], typing_extensions.Literal["auth_method"], typing_extensions.Literal["policy_id"], typing_extensions.Literal["allow_assumed_signin"], typing_extensions.Literal["tab_id"], typing_extensions.Literal["connector_id"], typing_extensions.Literal["created_at"], typing_extensions.Literal["updated_at"], typing_extensions.Literal["role_ids"], typing_extensions.Literal["provisioning"], typing_extensions.Literal["parameters"], typing_extensions.Literal["enforcement_point"], str, ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        id: typing.Union[MetaOapg.properties.id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        name: typing.Union[MetaOapg.properties.name, str, schemas.Unset] = schemas.unset,
        visible: typing.Union[MetaOapg.properties.visible, bool, schemas.Unset] = schemas.unset,
        description: typing.Union[MetaOapg.properties.description, str, schemas.Unset] = schemas.unset,
        notes: typing.Union[MetaOapg.properties.notes, str, schemas.Unset] = schemas.unset,
        icon_url: typing.Union[MetaOapg.properties.icon_url, str, schemas.Unset] = schemas.unset,
        auth_method: typing.Union['AuthMethod', schemas.Unset] = schemas.unset,
        policy_id: typing.Union[MetaOapg.properties.policy_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        allow_assumed_signin: typing.Union[MetaOapg.properties.allow_assumed_signin, bool, schemas.Unset] = schemas.unset,
        tab_id: typing.Union[MetaOapg.properties.tab_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        connector_id: typing.Union[MetaOapg.properties.connector_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        created_at: typing.Union[MetaOapg.properties.created_at, str, schemas.Unset] = schemas.unset,
        updated_at: typing.Union[MetaOapg.properties.updated_at, str, schemas.Unset] = schemas.unset,
        role_ids: typing.Union[MetaOapg.properties.role_ids, list, tuple, schemas.Unset] = schemas.unset,
        provisioning: typing.Union[MetaOapg.properties.provisioning, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        parameters: typing.Union['AppParameters', schemas.Unset] = schemas.unset,
        enforcement_point: typing.Union['EnforcementPoint', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[MetaOapg.additional_properties, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
    ) -> 'GenericApp':
        return super().__new__(
            cls,
            *_args,
            id=id,
            name=name,
            visible=visible,
            description=description,
            notes=notes,
            icon_url=icon_url,
            auth_method=auth_method,
            policy_id=policy_id,
            allow_assumed_signin=allow_assumed_signin,
            tab_id=tab_id,
            connector_id=connector_id,
            created_at=created_at,
            updated_at=updated_at,
            role_ids=role_ids,
            provisioning=provisioning,
            parameters=parameters,
            enforcement_point=enforcement_point,
            _configuration=_configuration,
            **kwargs,
        )

from onelogin.model.app_parameters import AppParameters
from onelogin.model.auth_method import AuthMethod
from onelogin.model.enforcement_point import EnforcementPoint
